/*
 * This file was generated automatically by xsubpp version 1.9508 from the
 * contents of Compare.xs. Do not edit this file, edit Compare.xs instead.
 *
 *	ANY CHANGES MADE HERE WILL BE LOST!
 *
 */

#line 1 "Compare.xs"
#include "EXTERN.h"
#include "perl.h"
#include "XSUB.h"

#include "ppport.h"


#line 18 "Compare.c"
#ifdef __cplusplus
extern "C"
#endif
XS(boot_Time__Compare); /* prototype to pass -Wmissing-prototypes */
XS(boot_Time__Compare)
{
    dXSARGS;

    XS_VERSION_BOOTCHECK ;

    XSRETURN_YES;
}

